California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Choose an Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
HERE ARE YOUR RESULTS: Election Dates (Dates appear according to the Election Cycle above) 2009 - 2010 Election Dates: 1. SPECIAL ELECTION Tuesday, 3/24/09 2. SPECIAL ELECTION RUNOFF Tuesday, 5/19/09 3. SPECIAL ELECTION Tuesday, 5/19/09 4. SPECIAL ELECTION Tuesday, 9/1/09 5. SPECIAL ELECTION Tuesday, 11/17/09 6. SPECIAL ELECTION RUNOFF Tuesday, 1/12/10 7. SPECIAL ELECTION Tuesday, 4/13/10 8. SPECIAL ELECTION Tuesday, 4/13/10 9. SPECIAL ELECTION RUNOFF Tuesday, 6/8/10 10. SPECIAL ELECTION RUNOFF Tuesday, 6/8/10 11. PRIMARY ELECTION Tuesday, 6/8/10 12. SPECIAL ELECTION Tuesday, 6/22/10 13. SPECIAL ELECTION RUNOFF Tuesday, 8/17/10 14. GENERAL ELECTION Tuesday, 11/2/10 15. SPECIAL ELECTION Tuesday, 11/2/10
If you are searching for campaign finance information related to a specific office this is the place to begin. Included are officeholders for Governor, Lieutenant Governor, Secretary of State, Attorney General, State Controller, State Treasurer, Insurance Commissioner, State Superintendent of Public Instruction, Board of Equalization, State Senate, and State Assembly. Here you will find their names, campaign committees, and other information.
STATEWIDE OFFICES
GOVERNOR
SCHWARZENEGGER, ARNOLD
| LIEUTENANT GOVERNOR
GARAMENDI, JOHN
SECRETARY OF STATE
BOWEN, DEBRA
| CONTROLLER
CHIANG, JOHN
TREASURER
LOCKYER, BILL
| ATTORNEY GENERAL
BROWN, EDMUND G. (JERRY)
SUPERINTENDENT OF PUBLIC INSTRUCTION
O'CONNELL, JACK
| INSURANCE COMMISSIONER
POIZNER, STEVE
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
YEE, BETTY T.
| MEMBER BOARD OF EQUALIZATION 02
LEONARD, BILL
MEMBER BOARD OF EQUALIZATION 03
STEEL, MICHELLE
| MEMBER BOARD OF EQUALIZATION 04
CHU, JUDY
SENATE DISTRICTS
STATE SENATE 01
VACANT
| STATE SENATE 02
WIGGINS, PATRICIA ANN
STATE SENATE 04
AANESTAD, SAMUEL M.
| STATE SENATE 05
WOLK, LOIS
STATE SENATE 06
STEINBERG, DARRELL
| STATE SENATE 07
DE SAULNIER, MARK
STATE SENATE 08
YEE, LELAND Y.
| STATE SENATE 09
HANCOCK, LONI
STATE SENATE 10
CORBETT, ELLEN
| STATE SENATE 11
SIMITIAN, S. JOSEPH
STATE SENATE 12
DENHAM, JEFF
| STATE SENATE 13
ALQUIST, ELAINE
STATE SENATE 14
COGDILL, DAVID E.
| STATE SENATE 15
BLAKESLEE, SAM
STATE SENATE 16
FLOREZ, DEAN
| STATE SENATE 17
RUNNER, GEORGE C.
STATE SENATE 18
ASHBURN, ROY
| STATE SENATE 19
STRICKLAND, TONY
STATE SENATE 20
PADILLA, ALEX
| STATE SENATE 21
LIU, CAROL
STATE SENATE 22
CEDILLO, GILBERT
| STATE SENATE 23
PAVLEY, FRAN
STATE SENATE 24
ROMERO, GLORIA
| STATE SENATE 25
WRIGHT, RODERICK "ROD"
STATE SENATE 26
PRICE, CURREN D.
| STATE SENATE 27
LOWENTHAL, ALAN
STATE SENATE 28
OROPEZA, JENNY
| STATE SENATE 29
HUFF, ROBERT 'BOB'
STATE SENATE 30
CALDERON, RONALD
| STATE SENATE 31
DUTTON, BOB
STATE SENATE 32
MC LEOD, GLORIA NEGRETE
| STATE SENATE 33
WALTERS, MIMI
STATE SENATE 34
CORREA, LOU
| STATE SENATE 35
HARMAN, TOM
STATE SENATE 36
HOLLINGSWORTH, DENNIS
| STATE SENATE 37
EMMERSON, BILL
STATE SENATE 38
WYLAND, MARK B.
| STATE SENATE 39
KEHOE, CHRISTINE
STATE SENATE 40
DUCHENY, DENISE MORENO
ASSEMBLY DISTRICTS
ASSEMBLY 01
CHESBRO, WESLEY
| ASSEMBLY 02
NIELSEN, JIM
ASSEMBLY 03
LOGUE, DANIEL R.
| ASSEMBLY 04
GAINES, EDWARD (TED) M.
ASSEMBLY 05
NIELLO, ROGER
| ASSEMBLY 06
HUFFMAN, JARED
ASSEMBLY 07
EVANS, NOREEN M.
| ASSEMBLY 08
YAMADA, MARIKO M.
ASSEMBLY 09
JONES, DAVE
| ASSEMBLY 10
HUBER, ALYSON
ASSEMBLY 11
TORLAKSON, TOM
| ASSEMBLY 12
MA, FIONA
ASSEMBLY 13
AMMIANO, TOM
| ASSEMBLY 14
SKINNER, NANCY
ASSEMBLY 15
BUCHANAN, JOAN
| ASSEMBLY 16
SWANSON, SANDRE
ASSEMBLY 17
GALGIANI, CATHLEEN A.
| ASSEMBLY 18
HAYASHI, MARY
ASSEMBLY 19
HILL, JERRY A.
| ASSEMBLY 20
TORRICO, ALBERTO
ASSEMBLY 21
RUSKIN, IRA
| ASSEMBLY 22
FONG, PAUL
ASSEMBLY 23
COTO, JOE
| ASSEMBLY 24
BEALL, JIM
ASSEMBLY 25
BERRYHILL, TOM
| ASSEMBLY 26
BERRYHILL, WILLIAM R.
ASSEMBLY 27
MONNING, WILLIAM W.
| ASSEMBLY 28
CABALLERO, ANNA
ASSEMBLY 29
VILLINES, MICHAEL N.
| ASSEMBLY 30
GILMORE, DANNY D.
ASSEMBLY 31
ARAMBULA, JUAN
| ASSEMBLY 32
FULLER, JEAN
ASSEMBLY 33
BLAKESLEE, SAM
| ASSEMBLY 34
CONWAY, CONNIE
ASSEMBLY 35
NAVA, PEDRO I.
| ASSEMBLY 36
KNIGHT, STEVE
ASSEMBLY 37
STRICKLAND, AUDRA
| ASSEMBLY 38
SMYTH, CAMERON
ASSEMBLY 39
FUENTES, FELIPE
| ASSEMBLY 40
BLUMENFIELD, BOB
ASSEMBLY 41
BROWNLEY, JULIA
| ASSEMBLY 42
FEUER, MICHAEL NELSON
ASSEMBLY 43
GATTO, MIKE
| ASSEMBLY 44
PORTANTINO, ANTHONY
ASSEMBLY 45
DE LEON, KEVIN
| ASSEMBLY 46
PEREZ, JOHN A.
ASSEMBLY 47
BASS, KAREN
| ASSEMBLY 48
DAVIS, MIKE
ASSEMBLY 49
ENG, MICHAEL
| ASSEMBLY 50
DE LA TORRE, HECTOR
ASSEMBLY 51
PRICE, CURREN D.
| ASSEMBLY 52
HALL, ISADORE
ASSEMBLY 53
LIEU, TED
| ASSEMBLY 54
LOWENTHAL, BONNIE
ASSEMBLY 55
FURUTANI, WARREN
| ASSEMBLY 56
MENDOZA, TONY
ASSEMBLY 57
HERNANDEZ, EDWARD P.
| ASSEMBLY 58
CALDERON, CHARLES M.
ASSEMBLY 59
ADAMS, ANTHONY
| ASSEMBLY 60
HAGMAN, CURT
ASSEMBLY 61
TORRES, NORMA
| ASSEMBLY 62
CARTER, WILMER AMINA
ASSEMBLY 63
EMMERSON, BILL
| ASSEMBLY 64
NESTANDE, BRIAN
ASSEMBLY 65
COOK, PAUL J.
| ASSEMBLY 66
JEFFRIES, KEVIN D.
ASSEMBLY 67
SILVA, JAMES W.
| ASSEMBLY 68
TRAN, VAN
ASSEMBLY 69
SOLORIO, JOSE
| ASSEMBLY 70
DE VORE, CHARLES S.
ASSEMBLY 71
MILLER, JEFF
| ASSEMBLY 72
NORBY, CHRIS
ASSEMBLY 73
HARKEY, DIANE
| ASSEMBLY 74
GARRICK, MARTIN W.
ASSEMBLY 75
FLETCHER, NATHAN B.
| ASSEMBLY 76
SALDANA, LORI
ASSEMBLY 77
ANDERSON, JOEL C.
| ASSEMBLY 78
BLOCK, MARTY J.
ASSEMBLY 79
SALAS, MARY H.
| ASSEMBLY 80
PEREZ, V. MANUEL